@@ -40,12 +40,10 @@ module Net
                 instruction = message.read_string
                 debug { "keyboard-interactive info request" }
 
-                if password.nil? && interactive? && prompter.nil?
-                  prompter = prompt.start(type: 'keyboard-interactive', name: name, instruction: instruction)
-                end
+                prompter = prompt.start(type: 'keyboard-interactive', name: name, instruction: instruction) if password.nil? && interactive? && prompter.nil?
 
                 _ = message.read_string # lang_tag
-                responses =[]
+                responses = []
 
                 message.read_long.times do
                   text = message.read_string
