@@ -1,18 +1,19 @@
-module Authentication; module Methods
-
-  module Common
-    include Net::SSH::Authentication::Constants
-
-    private
+module Authentication 
+  module Methods
 
+    module Common
+      include Net::SSH::Authentication::Constants
+  
+      private
+  
       def socket(options={})
         @socket ||= stub("socket", client_name: "me.ssh.test")
       end
-
+  
       def transport(options={})
         @transport ||= MockTransport.new(options.merge(socket: socket))
       end
-
+  
       def session(options={})
         @session ||= begin
           sess = stub("auth-session", logger: nil, transport: transport(options))
@@ -22,13 +23,14 @@ module Authentication; module Methods
           sess
         end
       end
-
+  
       def reset_session(options = {})
         @transport = nil
         @session = nil
         session(options)
       end
+  
+    end
 
   end
-
-end; end
\ No newline at end of file
+end
\ No newline at end of file
